==> phenoTest_1.0.0.tgz: phenoTest/doc/phenoTest.R <==
###################################################
### chunk number 1: loadLibAndData
###################################################
#line 45 "phenoTest.Rnw"
options(width=100)
library(phenoTest)
data(eset)
eset


###################################################
### chunk number 2: preprocess
###################################################
#line 60 "phenoTest.Rnw"
Tumor.size <- rnorm(ncol(eset),50,2)
pData(eset) <- cbind(pData(eset),Tumor.size)
pData(eset)[1:20,'lymph.node.status'] <- 'positive'


###################################################
### chunk number 3: setVars2test
###################################################
#line 86 "phenoTest.Rnw"
head(pData(eset))
survival <- matrix(c("Relapse","Months2Relapse"),ncol=2,byrow=TRUE)
colnames(survival) <- c('event','time')
vars2test <- list(survival=survival,categorical='lymph.node.status',continuous='Tumor.size')
vars2test


###################################################
### chunk number 4: runExpressionPhenoTest
###################################################
#line 98 "phenoTest.Rnw"
epheno <- ExpressionPhenoTest(eset,vars2test,p.adjust.method='none')
epheno


###################################################
### chunk number 5: pValueAdjust
###################################################
#line 107 "phenoTest.Rnw"
p.adjust.method(epheno)
epheno <- pAdjust(epheno,method='BH')
p.adjust.method(epheno)


###################################################
### chunk number 6: ephenoSubsetByName
###################################################
#line 135 "phenoTest.Rnw"
phenoNames(epheno)
epheno[,'Tumor.size']
epheno[,2]
epheno[,c(FALSE,FALSE,TRUE)]


###################################################
### chunk number 7: ephenoSubsetByClass
###################################################
#line 146 "phenoTest.Rnw"
phenoClass(epheno)
epheno[,phenoClass(epheno)=='survival']


###################################################
### chunk number 8: ephenoGetMeans
###################################################
#line 157 "phenoTest.Rnw"
head(getMeans(epheno))


###################################################
### chunk number 9: ephenoGetSummaries
###################################################
#line 171 "phenoTest.Rnw"
head(getSummaryDif(epheno))
head(getFc(epheno))
head(getHr(epheno))


###################################################
### chunk number 10: ephenoGetPvals
###################################################
#line 185 "phenoTest.Rnw"
head(getPvals(epheno))


###################################################
### chunk number 11: ephenoGetVars2test
###################################################
#line 193 "phenoTest.Rnw"
getVars2test(epheno)


###################################################
### chunk number 12: getSignatures
###################################################
#line 211 "phenoTest.Rnw"
sign1 <- featureNames(eset)[100:160]
sign2 <- featureNames(eset)[300:320]
mySignature <- list(sign1,sign2)
names(mySignature) <- c('My first signature','Another signature')
mySignature


###################################################
### chunk number 13: makeGeneSets
###################################################
#line 227 "phenoTest.Rnw"
library(GSEABase)
myGeneSetA <- GeneSet(geneIds=sign1, setName='My first signature')
myGeneSetB <- GeneSet(geneIds=sign2, setName='Another signature')
mySignature <- GeneSetCollection(myGeneSetA,myGeneSetB)
mySignature


###################################################
### chunk number 14: barplotSignifSignatures
###################################################
#line 247 "phenoTest.Rnw"
barplotSignifSignatures(epheno[,'lymph.node.status'],mySignature,alpha=0.85)


###################################################
### chunk number 15: barplotSignifSignatures
###################################################
#line 252 "phenoTest.Rnw"
#line 247 "phenoTest.Rnw"
barplotSignifSignatures(epheno[,'lymph.node.status'],mySignature,alpha=0.85)
#line 253 "phenoTest.Rnw"


###################################################
### chunk number 16: barplotSignatures
###################################################
#line 292 "phenoTest.Rnw"
barplotSignatures(epheno[,'Tumor.size'],mySignature)


###################################################
### chunk number 17: barplotSignatures
###################################################
#line 297 "phenoTest.Rnw"
#line 292 "phenoTest.Rnw"
barplotSignatures(epheno[,'Tumor.size'],mySignature)
#line 298 "phenoTest.Rnw"


###################################################
### chunk number 18: heatmapPhenoTestHeat
###################################################
#line 315 "phenoTest.Rnw"
pvals <- heatmapPhenoTest(eset,mySignature[[1]],vars2test=vars2test,heat.kaplan='heat')


###################################################
### chunk number 19: heatmapPhenoTestHeatPvals
###################################################
#line 320 "phenoTest.Rnw"
pvals


###################################################
### chunk number 20: heatmapPhenoTestHeat
###################################################
#line 327 "phenoTest.Rnw"
#line 315 "phenoTest.Rnw"
pvals <- heatmapPhenoTest(eset,mySignature[[1]],vars2test=vars2test,heat.kaplan='heat')
#line 328 "phenoTest.Rnw"


###################################################
### chunk number 21: heatmapPhenoTestKaplan
###################################################
#line 340 "phenoTest.Rnw"
pvals <- heatmapPhenoTest(eset,mySignature[[1]],vars2test=vars2test,heat.kaplan='kaplan')


###################################################
### chunk number 22: heatmapPhenoTestKaplanPvals
###################################################
#line 345 "phenoTest.Rnw"
pvals


###################################################
### chunk number 23: heatmapPhenoTest2
###################################################
#line 352 "phenoTest.Rnw"
#line 340 "phenoTest.Rnw"
pvals <- heatmapPhenoTest(eset,mySignature[[1]],vars2test=vars2test,heat.kaplan='kaplan')
#line 353 "phenoTest.Rnw"


###################################################
### chunk number 24: gsea
###################################################
#line 385 "phenoTest.Rnw"
set.seed('777')
my.gseaSignatures <- gseaSignatures(x=epheno,signatures=mySignature,B=1000)
my.gseaSignatures
my.gseaSignificance <- gseaSignificance(my.gseaSignatures,p.adjust='BH')
my.gseaSignificance
my.summary <- summary(my.gseaSignificance)
my.summary


###################################################
### chunk number 25: gseaPlot
###################################################
#line 399 "phenoTest.Rnw"
plot(my.gseaSignatures,my.gseaSignificance)


###################################################
### chunk number 26: plotGseaPrepare
###################################################
#line 410 "phenoTest.Rnw"
my.gseaSignatures <- gseaSignatures(x=epheno[,'Relapse'],signatures=mySignature[1],B=100)
my.gseaSignificance <- gseaSignificance(my.gseaSignatures,p.adjust='BH')
summary(my.gseaSignificance)


###################################################
### chunk number 27: plotGseaEs
###################################################
#line 415 "phenoTest.Rnw"
plot(my.gseaSignatures,my.gseaSignificance,es.nes='es')  


###################################################
### chunk number 28: plotGsea
###################################################
#line 420 "phenoTest.Rnw"
#line 415 "phenoTest.Rnw"
plot(my.gseaSignatures,my.gseaSignificance,es.nes='es')  
#line 421 "phenoTest.Rnw"


###################################################
### chunk number 29: plotGseaWilcoxPrepare
###################################################
#line 444 "phenoTest.Rnw"
my.gseaSignatures <- gseaSignatures(x=epheno[,'Relapse'],signatures=mySignature[1],B=100,test='wilcox')
my.gseaSignificance <- gseaSignificance(my.gseaSignatures,p.adjust='BH')
summary(my.gseaSignificance)


###################################################
### chunk number 30: plotGseaWilcox
###################################################
#line 449 "phenoTest.Rnw"
plot(my.gseaSignatures,my.gseaSignificance)  


###################################################
### chunk number 31: plotGseaWilcox
###################################################
#line 454 "phenoTest.Rnw"
#line 449 "phenoTest.Rnw"
plot(my.gseaSignatures,my.gseaSignificance)  
#line 455 "phenoTest.Rnw"

==> phenoTest_1.6.0.tgz: phenoTest/doc/phenoTest.R <==
### R code from vignette source 'phenoTest.Rnw'

###################################################
### code chunk number 1: loadLibAndData
###################################################
options(width=100)
library(phenoTest)
data(eset)
eset


###################################################
### code chunk number 2: preprocess
###################################################
Tumor.size <- rnorm(ncol(eset),50,2)
pData(eset) <- cbind(pData(eset),Tumor.size)
pData(eset)[1:20,'lymph.node.status'] <- 'positive'


###################################################
### code chunk number 3: setVars2test
###################################################
head(pData(eset))
survival <- matrix(c("Relapse","Months2Relapse"),ncol=2,byrow=TRUE)
colnames(survival) <- c('event','time')
vars2test <- list(survival=survival,categorical='lymph.node.status',continuous='Tumor.size')
vars2test


###################################################
### code chunk number 4: runExpressionPhenoTest
###################################################
epheno <- ExpressionPhenoTest(eset,vars2test,p.adjust.method='none')
epheno


###################################################
### code chunk number 5: pValueAdjust
###################################################
p.adjust.method(epheno)
epheno <- pAdjust(epheno,method='BH')
p.adjust.method(epheno)


###################################################
### code chunk number 6: ephenoSubsetByName
###################################################
phenoNames(epheno)
epheno[,'Tumor.size']
epheno[,2]
epheno[,c(FALSE,FALSE,TRUE)]


###################################################
### code chunk number 7: ephenoSubsetByClass
###################################################
phenoClass(epheno)
epheno[,phenoClass(epheno)=='survival']


###################################################
### code chunk number 8: ephenoGetMeans
###################################################
head(getMeans(epheno))


###################################################
### code chunk number 9: ephenoGetSummaries
###################################################
head(getSummaryDif(epheno))
head(getFc(epheno))
head(getHr(epheno))


###################################################
### code chunk number 10: ephenoGetSignif
###################################################
head(getSignif(epheno))


###################################################
### code chunk number 11: ephenoGetVars2test
###################################################
getVars2test(epheno)


###################################################
### code chunk number 12: getSignatures
###################################################
set.seed(777)
sign1 <- sample(featureNames(eset))[1:20]
sign2 <- sample(featureNames(eset))[1:50]
mySignature <- list(sign1,sign2)
names(mySignature) <- c('My first signature','Another signature')
mySignature


###################################################
### code chunk number 13: makeGeneSets
###################################################
library(GSEABase)
myGeneSetA <- GeneSet(geneIds=sign1, setName='My first signature')
myGeneSetB <- GeneSet(geneIds=sign2, setName='Another signature')
mySignature <- GeneSetCollection(myGeneSetA,myGeneSetB)
mySignature


###################################################
### code chunk number 14: barplotSignifSignatures
###################################################
barplotSignifSignatures(epheno[,'lymph.node.status'],mySignature,alpha=0.99)


###################################################
### code chunk number 15: barplotSignifSignatures
###################################################
barplotSignifSignatures(epheno[,'lymph.node.status'],mySignature,alpha=0.99)


###################################################
### code chunk number 16: barplotSignatures
###################################################
barplotSignatures(epheno[,'Tumor.size'],mySignature)


###################################################
### code chunk number 17: barplotSignatures
###################################################
barplotSignatures(epheno[,'Tumor.size'],mySignature)


###################################################
### code chunk number 18: heatmapPhenoTestHeat
###################################################
pvals <- heatmapPhenoTest(eset,mySignature[[1]],vars2test=vars2test,heat.kaplan='heat')


###################################################
### code chunk number 19: heatmapPhenoTestHeatPvals
###################################################
pvals


###################################################
### code chunk number 20: heatmapPhenoTestHeat
###################################################
pvals <- heatmapPhenoTest(eset,mySignature[[1]],vars2test=vars2test,heat.kaplan='heat')


###################################################
### code chunk number 21: heatmapPhenoTestKaplan
###################################################
pvals <- heatmapPhenoTest(eset,mySignature[[1]],vars2test=vars2test,heat.kaplan='kaplan')


###################################################
### code chunk number 22: heatmapPhenoTestKaplanPvals
###################################################
pvals


###################################################
### code chunk number 23: heatmapPhenoTest2
###################################################
pvals <- heatmapPhenoTest(eset,mySignature[[1]],vars2test=vars2test,heat.kaplan='kaplan')


###################################################
### code chunk number 24: gsea
###################################################
my.gsea <- gsea(x=epheno,gsets=mySignature,B=1000,p.adjust='BH')
my.gsea
summary(my.gsea)


###################################################
### code chunk number 25: gseaPlot
###################################################
plot(my.gsea)


###################################################
### code chunk number 26: plotGseaPrepare
###################################################
my.gsea <- gsea(x=epheno[,'Relapse'],gsets=mySignature[1],B=100,p.adjust='BH')
summary(my.gsea)


###################################################
### code chunk number 27: plotGseaEs
###################################################
plot(my.gsea,es.nes='es',selGsets='My first signature')  


###################################################
### code chunk number 28: plotGsea
###################################################
plot(my.gsea,es.nes='es',selGsets='My first signature')  


###################################################
### code chunk number 29: plotGseaWilcoxPrepare
###################################################
my.gsea <- gsea(x=epheno[,'Relapse'],gsets=mySignature,B=100,test='wilcox',p.adjust='BH')
summary(my.gsea)


###################################################
### code chunk number 30: plotGseaWilcox
###################################################
plot(my.gsea,selGsets='My first signature')


###################################################
### code chunk number 31: plotGseaWilcox
###################################################
plot(my.gsea,selGsets='My first signature')
